@@ -42,13 +42,18 @@
 #' If the \code{id} is checked in TOC then the data will saved in the cache with the date from the "lastUpdate" column from the TOC, otherwise it is saved with the current date.  
 #' @return a data.table with the following columns if the default \code{melt=TRUE} is used:
 #'  \tabular{ll}{
-#'      \code{FREQ} \tab The frequency of the data (\strong{A}nnual, \strong{S}emi-annual, \strong{H}alf-year, \strong{Q}uarterly, \strong{M}onthly, \strong{W}eekly, \strong{D}aily)\cr
-#'      dimension names \tab One column for each dimension in the data \cr
-#'      \code{TIME_FORMAT} \tab A column for the time format, if the source file SDMX and the data was not loaded from a previously cached TSV download (this column is missing if the source file is TSV) \cr
-#'      \code{time/TIME_PERIOD} \tab A column for the time dimension, where the name of the column depends on the source file (TSV/SDMX)\cr
-#'      \code{values/OBS_VALUE} \tab A column for numerical values, where the name of the column depends on the source file (TSV/SDMX)\cr
-#'      \code{flags/OBS_STATUS} \tab A column for flags if the \code{keep_flags=TRUE} otherwise this column is not included in the data table, and the name of the column depends on the source file (TSV/SDMX)
-#'    }
+#'  \code{FREQ} \tab The frequency of the data (\strong{A}nnual, \strong{S}emi-annual, \strong{H}alf-year, \strong{Q}uarterly, \strong{M}onthly,
+#'  \strong{W}eekly, \strong{D}aily)\cr
+#'  dimension names \tab One column for each dimension in the data\cr
+#'  \code{TIME_FORMAT} \tab A column for the time format, if the source file SDMX and the data was not
+#'  loaded from a previously cached TSV download (this column is missing if the source file is TSV)\cr
+#'  \code{time/TIME_PERIOD} \tab A column for the time dimension, where the name of the column depends on the
+#'  source file (TSV/SDMX)\cr
+#'  \code{values/OBS_VALUE} \tab A column for numerical values, where the name of the column depends on the
+#'  source file (TSV/SDMX)\cr
+#'  \code{flags/OBS_STATUS} \tab A column for flags if the \code{keep_flags=TRUE} otherwise this column is not included
+#'  in the data table, and the name of the column depends on the source file (TSV/SDMX)
+#'  }
 #' The data does not include all missing values. The missing values are dropped if the value and flags are missing
 #' on a particular time. 
 #' 
@@ -243,6 +248,8 @@ get_eurostat_raw <- function(id,
           }else{
             restat_raw<-data.table::rbindlist(parallel::mclapply(xml_leafs,extract_data,keep_flags=keep_flags,stringsAsFactors=stringsAsFactors,mc.cores=getOption("restatapi_cores",1L)))                                  
           }
+        } else{
+          message("Could not download the SDMX file, use the verbose option to see the exact cause of the error.")
         }
       }
     }
