@@ -11,22 +11,29 @@
 #'         Can be set also with \code{options(restatapi_verbose=TRUE)}
 #' @param ... parameter to pass on the \code{load_cfg} function
 #' @return A data table with the following columns:
-#'    \tabular{ll}{
-#'      \code{title} \tab The name of dataset/table in the language provided by the \code{lang} parameter \cr
-#'      \code{code} \tab The codename of dataset/table which can be used as \code{id} in other functions \cr
-#'      \code{type} \tab The type of information: 'dataset' or 'table' \cr
-#'      \code{lastUpdate} \tab The date when the data was last time updated for tables and datasets\cr
-#'      \code{lastModified}\tab The date when the structure of the dataset/table was last time modified\cr
-#'      \code{dataStart}\tab The start date of the data in the dataset/table\cr
-#'      \code{dataEnd}\tab The end date of the data in the dataset/table\cr
-#'      \code{values}\tab The number of values in the dataset/table, and it is filled only if the download \code{mode} is "xml"\cr
-#'      \code{unit}\tab The unit name for tables in the language provided by the \code{lang} parameter, for dataset it is empty and this column exists only if the download \code{mode} is "xml"\cr
-#'      \code{shortDescription}\tab The short description of the values for tables in the language provided by the \code{lang} parameter, for dataset it is empty and this column exists only if the download \code{mode} is "xml"\cr
-#'      \code{metadata.html}\tab The link to the metadata in html format, and this column exists only if the download \code{mode} is "xml"\cr
-#'      \code{metadata.sdmx}\tab The link to the metadata in SDMX format, and this column exists only if the download \code{mode} is "xml"\cr
-#'      \code{downloadLink.tsv}\tab The link to the whole dataset/table in tab separated values format in the bulk download facility and this column exists only if the download \code{mode} is "xml"\cr
-#'      \code{downloadLink.sdmx}\tab The link to the whole dataset/table in SDMX format in the bulk download facility and this column exists only if the download \code{mode} is "xml"
-#'    }
+#'  \tabular{ll}{
+#'  \code{title} \tab The name of dataset/table in the language provided by the \code{lang} parameter\cr
+#'  \code{code} \tab The codename of dataset/table which can be used as \code{id} in other functions\cr
+#'  \code{type} \tab The type of information: 'dataset' or 'table'\cr
+#'  \code{lastUpdate} \tab The date when the data was last time updated for tables and datasets\cr
+#'  \code{lastModified}\tab The date when the structure of the dataset/table was last time modified\cr
+#'  \code{dataStart}\tab The start date of the data in the dataset/table\cr
+#'  \code{dataEnd}\tab The end date of the data in the dataset/table\cr
+#'  \code{values}\tab The number of values in the dataset/table, and it is filled only if the download
+#'  \code{mode} is "xml"\cr
+#'  \code{unit}\tab The unit name for tables in the language provided by the \code{lang} parameter, for
+#'  dataset it is empty and this column exists only if the download \code{mode} is "xml"\cr
+#'  \code{shortDescription}\tab The short description of the values for tables in the language provided by the
+#'  \code{lang} parameter, for dataset it is empty and this column exists only if the download \code{mode} is "xml"\cr
+#'  \code{metadata.html}\tab The link to the metadata in html format, and this column exists only if the
+#'  download \code{mode} is "xml"\cr
+#'  \code{metadata.sdmx}\tab The link to the metadata in SDMX format, and this column exists only if the
+#'  download \code{mode} is "xml"\cr
+#'  \code{downloadLink.tsv}\tab The link to the whole dataset/table in tab separated values format in the bulk
+#'  download facility and this column exists only if the download \code{mode} is "xml"\cr
+#'  \code{downloadLink.sdmx}\tab The link to the whole dataset/table in SDMX format in the bulk download
+#'  facility and this column exists only if the download \code{mode} is "xml"
+#'  }
 #' @export
 #' @seealso \code{\link{search_eurostat_toc}}, \code{\link{get_eurostat_dsd}}, \code{\link{get_eurostat_raw}}, \code{\link{get_eurostat_bulk}}, \code{\link{get_eurostat_data}}.
 #' @details The TOC is downloaded from Eurostat websites through the REST API for the \code{xml} (default) version or from the bulk download facilities for \code{txt} version.
@@ -100,13 +107,15 @@ get_eurostat_toc<-function(mode="xml",
                    if (verbose) {message("get_eurostat_toc - Warning by the reading of the tsv version of the TOC file:",'\n',paste(unlist(w),collapse="\n"))}
                    tbc<-FALSE
                  })
-        if(tbc) {
-          names(toc)<-c("title","code","type","lastUpdate","lastModified","dataStart","dataEnd","values")
-          toc<-toc[toc$type!="folder",]
-          toc$title<-sub("^\\s*","",toc$title)
-          unlink(temp)
+        if (tbc) {
+          if (!is.null(toc)) {
+            names(toc)<-c("title","code","type","lastUpdate","lastModified","dataStart","dataEnd","values")
+            toc<-toc[toc$type!="folder",]
+            toc$title<-sub("^\\s*","",toc$title)
+          }
         }
-      }  
+      }
+      unlink(temp)
     } else if (mode=="xml"){
       toc_endpoint<-eval(parse(text=paste0("cfg$TOC_ENDPOINT$'",rav,"'$ESTAT$xml")))
       if (verbose) {message("get_eurostat_toc - Downloading ",toc_endpoint)}
