@@ -109,8 +109,10 @@ nc1<-ncol(dt1)
 t2<-system.time({dt2<-get_eurostat_data(testid2,stringsAsFactors=FALSE)})[3]
 nc2<-ncol(dt2)
 if (!is.null(dt1)&is.data.frame(dt1)&!is.null(dt2)&is.data.frame(dt2)&!is.null(xml_toc)){
-  message("\n ########--------- 21 test of the get_eurostat_data function")
-  expect_equal(nrow(dt1),as.numeric(xml_toc$values[xml_toc$code==testid2]))
+  if (!is.na(as.numeric(xml_toc$values[xml_toc$code==testid2]))){
+    message("\n ########--------- 21 test of the get_eurostat_data function")
+    expect_equal(nrow(dt1),as.numeric(xml_toc$values[xml_toc$code==testid2]))
+  }
   message("\n ########--------- 22 test of the get_eurostat_data function")
   expect_equal(nc2+1,nc1)
   message("\n ########--------- 23 test of the get_eurostat_data function")
@@ -187,8 +189,10 @@ if (!is.null(dt8)){
 }
 dt9<-get_eurostat_data(testid4,filters="2018",cflags=TRUE)
 if (!is.null(dt9)&is.data.frame(dt9)&!is.null(xml_toc)){
-  message("\n ########--------- 46 test of filtering in the get_eurostat_data function")
-  expect_equal(nrow(dt9),as.numeric(xml_toc$values[xml_toc$code==testid4]))
+  if (!is.na(as.numeric(xml_toc$values[xml_toc$code==testid4]))){
+    message("\n ########--------- 46 test of filtering in the get_eurostat_data function")
+    expect_equal(nrow(dt9),as.numeric(xml_toc$values[xml_toc$code==testid4]))
+  }
 }  
 dsd1<-get_eurostat_dsd(testid4)
 dsd2<-get_eurostat_dsd(testid6)
@@ -234,14 +238,16 @@ if (!is.null(dsd1)&is.data.frame(dsd1)){
 }  
 
 udate<-format(Sys.Date(),"%Y.%m.%d")
-if (!is.null(xml_toc)) {udate2<-xml_toc$lastUpdate[xml_toc$code==testid5]}
+if (!is.null(xml_toc)) {udate2<-xml_toc$lastUpdate[xml_toc$code==testid5]} else {udate2<-NULL}
 if (!is.null(dt1)&is.data.frame(dt1)&!is.null(rt3)&is.data.frame(rt3)&!is.null(rt4)&is.data.frame(rt4)&!is.null(rt5)&is.data.frame(rt5)&!is.null(bt2)&is.data.frame(bt2)&!is.null(bt3)&is.data.frame(bt3)){
-  message("\n ########--------- 54 test of the get/put_eurostat_cache function")
-  expect_false(exists(paste0("b_avia_par_me-",udate,"-0-0-Q"),envir=.restatapi_env))
+  if (!is.null(udate2)){
+    message("\n ########--------- 54 test of the get/put_eurostat_cache function")
+    expect_true(exists(paste0("r_irt_h_eurcoe_d-",udate2,"-1"),envir=.restatapi_env))
+  }
   message("\n ########--------- 55 test of the get/put_eurostat_cache function")
-  expect_true(exists(paste0("r_irt_h_eurcoe_d-",udate,"-0"),envir=.restatapi_env))
+  expect_false(exists(paste0("b_avia_par_me-",udate,"-0-0-Q"),envir=.restatapi_env))
   message("\n ########--------- 56 test of the get/put_eurostat_cache function")
-  expect_true(exists(paste0("r_irt_h_eurcoe_d-",udate2,"-1"),envir=.restatapi_env))
+  expect_true(exists(paste0("r_irt_h_eurcoe_d-",udate,"-0"),envir=.restatapi_env))
   message("\n ########--------- 57 test of the get/put_eurostat_cache function")
   expect_true(exists(paste0("b_agr_r_milkpr-",udate,"-0-0"),envir=.restatapi_env))
   message("\n ########--------- 58 test of the get/put_eurostat_cache function")
@@ -433,8 +439,10 @@ if (grepl("\\.amzn|-aws",Sys.info()['release'])) {
     expect_message(raw<-get_eurostat_raw(testid6,mode="text"))
     message("\n ########--------- 111 additional tests for the get_eurostat_raw/bulk function")
     expect_equal(nrow(raw_xml),nrow(raw_txt))
-    message("\n ########--------- 112 additional tests for the get_eurostat_raw/bulk function")
-    expect_equal(nrow(raw_txt),as.numeric(xml_toc$values[xml_toc$code==testid6]))
+    if (!is.na(as.numeric(xml_toc$values[xml_toc$code==testid6]))){
+      message("\n ########--------- 112 additional tests for the get_eurostat_raw/bulk function")
+      expect_equal(nrow(raw_txt),as.numeric(xml_toc$values[xml_toc$code==testid6]))
+    }
     message("\n ########--------- 113 additional tests for the get_eurostat_raw/bulk function")
     expect_true(ncol(raw_xml)>ncol(bulk))
     message("\n ########--------- 114 additional tests for the get_eurostat_raw/bulk function")
@@ -531,7 +539,7 @@ if (grepl("\\.amzn|-aws",Sys.info()['release'])) {
 
   clean_restatapi_cache()
   xml_toc<-get_eurostat_toc(verbose=TRUE)
-  if (!is.null(xml_toc)) {udate2<-xml_toc$lastUpdate[xml_toc$code==testid12]}
+  # if (!is.null(xml_toc)) {udate2<-xml_toc$lastUpdate[xml_toc$code==testid12]} else {udate2<-NULL}
   udate<-format(Sys.Date(),"%Y.%m.%d")
   nm<-paste0("r_", testid12,"-",udate)
   rt1<-system.time(raw1<-get_eurostat_raw(testid12,"xml",keep_flags=TRUE,stringsAsFactors=TRUE,verbose=TRUE))[3]
